CustomBarcode constructor
Creates a CustomBarcode widget.
The barcode parameter must contain the barcode configuration data.
Implementation
const CustomBarcode({super.key, required this.barcode});
Creates a CustomBarcode widget.
The barcode parameter must contain the barcode configuration data.
const CustomBarcode({super.key, required this.barcode});