LayoutReceipt class

The main receipt layout widget that renders JSON receipt data.

This widget takes JSON-formatted receipt data and renders it as a Flutter widget with proper styling and layout.

Inheritance

Constructors

LayoutReceipt({Key? key, required String jsonContent, required double maxWidth, Uint8List? imageHeader, Uint8List? imageFooter, int margin = 0})
Creates a LayoutReceipt widget.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageFooter → Uint8List?
Optional footer image to display at the bottom of the receipt.
final
imageHeader → Uint8List?
Optional header image to display at the top of the receipt.
final
jsonContent → String
The JSON string containing the receipt structure and data.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → int
Horizontal margin/padding in pixels.
final
maxWidth → double
The maximum width of the receipt in pixels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited